summaryrefslogtreecommitdiffstats
path: root/src/server/CompiledPatch.hpp
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2012-08-18 23:05:06 +0000
committerDavid Robillard <d@drobilla.net>2012-08-18 23:05:06 +0000
commit317627ef40f7654c298aa1ac707851c852259e3a (patch)
tree38f7ed57aafb7b3b8e21e6caa3429a39207e4a9a /src/server/CompiledPatch.hpp
parent160b2baf7df8b960f22619c013b3197c0dc51c2b (diff)
downloadingen-317627ef40f7654c298aa1ac707851c852259e3a.tar.gz
ingen-317627ef40f7654c298aa1ac707851c852259e3a.tar.bz2
ingen-317627ef40f7654c298aa1ac707851c852259e3a.zip
Node => Block
git-svn-id: http://svn.drobilla.net/lad/trunk/ingen@4720 a436a847-0d15-0410-975c-d299462d15a1
Diffstat (limited to 'src/server/CompiledPatch.hpp')
-rw-r--r--src/server/CompiledPatch.hpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/src/server/CompiledPatch.hpp b/src/server/CompiledPatch.hpp
index 7f973792..15d1137a 100644
--- a/src/server/CompiledPatch.hpp
+++ b/src/server/CompiledPatch.hpp
@@ -27,42 +27,42 @@ namespace Ingen {
namespace Server {
class EdgeImpl;
-class NodeImpl;
+class BlockImpl;
-/** All information required about a node to execute it in an audio thread.
+/** All information required about a block to execute it in an audio thread.
*/
-class CompiledNode {
+class CompiledBlock {
public:
- CompiledNode(NodeImpl* n, size_t np, const std::list<NodeImpl*>& d)
- : _node(n), _n_providers(np)
+ CompiledBlock(BlockImpl* b, size_t np, const std::list<BlockImpl*>& d)
+ : _block(b), _n_providers(np)
{
// Copy to a vector for maximum iteration speed and cache optimization
// (Need to take a copy anyway)
_dependants.reserve(d.size());
- for (std::list<NodeImpl*>::const_iterator i = d.begin(); i != d.end(); ++i)
+ for (std::list<BlockImpl*>::const_iterator i = d.begin(); i != d.end(); ++i)
_dependants.push_back(*i);
}
- NodeImpl* node() const { return _node; }
- size_t n_providers() const { return _n_providers; }
- const std::vector<NodeImpl*>& dependants() const { return _dependants; }
+ BlockImpl* block() const { return _block; }
+ size_t n_providers() const { return _n_providers; }
+ const std::vector<BlockImpl*>& dependants() const { return _dependants; }
private:
- NodeImpl* _node;
- size_t _n_providers; ///< Number of input ready signals to trigger run
- std::vector<NodeImpl*> _dependants; ///< Nodes this one's output ports are connected to
+ BlockImpl* _block;
+ size_t _n_providers; ///< Number of input ready signals to trigger run
+ std::vector<BlockImpl*> _dependants; ///< Blocks this one's output ports are connected to
};
/** A patch ``compiled'' into a flat structure with the correct order so
* the audio thread(s) can execute it without threading problems (since
* the preprocessor thread modifies the graph).
*
* The nodes contained here are sorted in the order they must be executed.
* The parallel processing algorithm guarantees no node will be executed
* before its providers, using this order as well as semaphores.
*/
-class CompiledPatch : public std::vector<CompiledNode>
+class CompiledPatch : public std::vector<CompiledBlock>
, public Raul::Disposable
, public Raul::Noncopyable
{
@@ -27,42 +27,42 @@ namespace Ingen {
* the preprocessor thread modifies the graph).
*
- * The nodes contained here are sorted in the order they must be executed.
- * The parallel processing algorithm guarantees no node will be executed
+ * The blocks contained here are sorted in the order they must be executed.
+ * The parallel processing algorithm guarantees no block will be executed
* before its providers, using this order as well as semaphores.
*/